@@ -1,17 +1,18 @@
 #  Copyright (c) 2022 Szymon Mikler
 
-from . import graph_algorithms, model_tools
+from . import graph_algorithms, model_tools, symbolic_data
 from .config import optimize_module_calls
-from .functions_utility import add_to_model
+from .functions_utility import add_to_graph
+from .symbolic_data import CustomInput, Input
 from .symbolic_model import SymbolicModel
-from .symbolic_tensor import Input, SymbolicTensor
 
 __all__ = [
     "Input",
+    "CustomInput",
     "SymbolicModel",
-    "SymbolicTensor",
-    "add_to_model",
+    "add_to_graph",
     "graph_algorithms",
     "model_tools",
     "optimize_module_calls",
+    "symbolic_data",
 ]
